Contributing
============

Please file bugs to the `Github issue tracker`_.  Pull requests are welcome.

.. _Github issue tracker: https://github.com/davidsamir/credit-card-generator


Hacking and Pull Requests
-------------------------

Opening your pull request sooner will allow others to comment on it sooner.

A checklist of things to remember when making a feature:

- Write tests if applicable
- Update the `README`_ file if needed
- Update the documentation if needed
- Add yourself to the `AUTHORS`_ file

.. _AUTHORS: AUTHORS.rst
.. _README: README.rst
